==> haskell-protolude-0.1.10-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-protolude.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: protolude
version: 0.1.10
id: protolude-0.1.10-1kCxJX2E17rJ48dhoo0lw1
key: protolude-0.1.10-1kCxJX2E17rJ48dhoo0lw1
license: MIT
copyright: 2016 Stephen Diehl
maintainer: stephen.m.diehl@gmail.com
homepage: https://github.com/sdiehl/protolude
synopsis: A sensible set of defaults for writing custom Preludes.
description:
    A sensible set of defaults for writing custom Preludes.
category: Prelude
author: Stephen Diehl
exposed: True
exposed-modules:
    Protolude Unsafe Base Applicative Bool Debug List Monad Show Conv
    Either Functor Semiring Bifunctor Exceptions Panic
abi: 4e47bf7087f42f8151e6a3b767ae5d4e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/protolude-0.1.10
library-dirs: /usr/lib/ghc-8.0.1/site-local/protolude-0.1.10
data-dir: /usr/share/arm-linux-ghc-8.0.1/protolude-0.1.10
hs-libraries: HSprotolude-0.1.10-1kCxJX2E17rJ48dhoo0lw1
depends:
    async-2.1.1-9CmNvQft9hOA1w6AR7WdJM base-4.9.0.0 bytestring-0.10.8.1
    containers-0.5.7.1 deepseq-1.4.2.0 ghc-prim-0.5.0.0
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM safe-0.3.11-Ck0Z7kfzoQA1bcHU9bHvtW
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-protolude/html/protolude.haddock
haddock-html: /usr/share/doc/haskell-protolude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-protolude-0.1.10-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-protolude.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: protolude
version: 0.1.10
id: protolude-0.1.10-C12kRgN5t6pLZslg4Bjv6Z
key: protolude-0.1.10-C12kRgN5t6pLZslg4Bjv6Z
license: MIT
copyright: 2016 Stephen Diehl
maintainer: stephen.m.diehl@gmail.com
homepage: https://github.com/sdiehl/protolude
synopsis: A sensible set of defaults for writing custom Preludes.
description:
    A sensible set of defaults for writing custom Preludes.
category: Prelude
author: Stephen Diehl
exposed: True
exposed-modules:
    Protolude Unsafe Base Applicative Bool Debug List Monad Show Conv
    Either Functor Semiring Bifunctor Exceptions Panic
abi: 0b2d31ab0e7c38c3c0898e9575d49cc3
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/protolude-0.1.10
library-dirs: /usr/lib/ghc-8.0.1/site-local/protolude-0.1.10
data-dir: /usr/share/arm-linux-ghc-8.0.1/protolude-0.1.10
hs-libraries: HSprotolude-0.1.10-C12kRgN5t6pLZslg4Bjv6Z
depends:
    async-2.1.1-9CmNvQft9hOA1w6AR7WdJM base-4.9.0.0 bytestring-0.10.8.1
    containers-0.5.7.1 deepseq-1.4.2.0 ghc-prim-0.5.0.0
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM safe-0.3.12-AllanCJRaxaAIEhwGWDhwA
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-protolude/html/protolude.haddock
haddock-html: /usr/share/doc/haskell-protolude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
